package
Version:
v0.0.0-...-4584b12
Opens a new window with list of versions in this module.
Published: May 21, 2024
License: BSD-3-Clause
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type User struct {
gorm.Model
ID int `gorm:"primaryKey;autoIncrement;"`
Username string `gorm:"unique"`
Email string `gorm:"unique"`
Password string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.